# CLI

Cadwyn has an optional CLI that can be installed with `pip install 'cadwyn[standard]'`.

Its main purpose is [to render generated schemas](./schema_generation.md#rendering-schemas).

You can check the current version of Cadwyn using the CLI:

```bash
cadwyn --version
```
